@@ -246,6 +246,10 @@ sub new {
             my ($self) = @_;
             $self->_start_whitespace_ping;
             $self->unreg_me;
+         },
+         disconnect => sub {
+            $self->_stop_whitespace_ping;
+            $self->unreg_me;
          }
       );
    }
@@ -897,6 +901,10 @@ sub _start_whitespace_ping {
       });
 }
 
+sub _stop_whitespace_ping {
+   delete $_[0]->{_ws_ping};
+}
+
 
 =item B<jid>
 
